# Generated by Django 4.1.7 on 2023-03-17 11:57

from django.db import migrations
import wagtail.blocks
import wagtail.fields
import wagtail.images.blocks


class Migration(migrations.Migration):

    dependencies = [
        ('home', '0002_create_homepage'),
    ]

    operations = [
        migrations.AddField(
            model_name='homepage',
            name='content',
            field=wagtail.fields.StreamField([('message_form', wagtail.blocks.StructBlock([('form_name', wagtail.blocks.CharBlock()), ('fields', wagtail.blocks.StreamBlock([('text', wagtail.blocks.StructBlock([('name', wagtail.blocks.CharBlock()), ('label', wagtail.blocks.CharBlock()), ('is_required', wagtail.blocks.BooleanBlock(default=True, required=False))])), ('check', wagtail.blocks.StructBlock([('name', wagtail.blocks.CharBlock()), ('label', wagtail.blocks.CharBlock()), ('is_required', wagtail.blocks.BooleanBlock(default=True, required=False))])), ('submit_button', wagtail.blocks.StructBlock([('button_text', wagtail.blocks.CharBlock())])), ('image', wagtail.images.blocks.ImageChooserBlock()), ('rich_text', wagtail.blocks.RichTextBlock(features=['bold', 'italic']))])), ('send_emails_to', wagtail.blocks.EmailBlock())]))], default=None, use_json_field=False),
            preserve_default=False,
        ),
    ]
